@@ -23,7 +23,7 @@ def codetest(code, lang, langv = "None", cid = "2c1d7916a28c2ac644a6acb7abdf8847
     "clientId": cid,
     "clientSecret": secret,
     "script": code,
-    "language": lang,
+    "language": languages.get(lang),
     "versionIndex": langv}
   req = requests.post(url, json = jsun)
   result = json.loads(req.text)
